@@ -836,8 +836,8 @@ O_plot <- function(spct,
   }
 
   molten.spct <-
-    tidyr::gather_(dplyr::select_(spct, "w.length", "Tfr", "Afr", "Rfr"),
-                   "variable", "value", c("Tfr", "Afr", "Rfr"))
+    tidyr::gather(dplyr::select(spct, c("w.length", "Tfr", "Afr", "Rfr")),
+                   key = "variable", value = "value", c("Tfr", "Afr", "Rfr"))
   stack.levels <- c("Tfr", "Afr", "Rfr")
   if (utils::compareVersion(
     asNamespace("ggplot2")$`.__NAMESPACE__.`$spec[["version"]],
@@ -1047,7 +1047,7 @@ autoplot.filter_spct <-
       stop("Invalid 'plot.qty' argument value: '", plot.qty, "'")
     }
     out.ggplot +
-      ggtitle_spct(object = object,
+      autotitle(object = object,
                    time.format = time.format,
                    tz = tz,
                    object.label = object.label,
@@ -1186,7 +1186,7 @@ autoplot.reflector_spct <-
       stop("Invalid 'plot.qty' argument value: '", plot.qty, "'")
     }
     out.ggplot +
-      ggtitle_spct(object = object,
+      autotitle(object = object,
                    time.format = time.format,
                    tz = tz,
                    object.label = object.label,
@@ -1382,7 +1382,7 @@ autoplot.object_spct <-
       stop("Invalid 'plot.qty' argument value: '", plot.qty, "'")
     }
     out.ggplot +
-      ggtitle_spct(object = object,
+      autotitle(object = object,
                    time.format = time.format,
                    tz = tz,
                    object.label = object.label,
