@@ -299,7 +299,7 @@ autoplot.raw_spct <-
              ylim = ylim,
              na.rm = na.rm,
              ...) +
-      ggtitle_spct(object = object,
+      autotitle(object = object,
                    time.format = time.format,
                    tz = tz,
                    object.label = object.label,
